@@ -7,3 +7,7 @@ my $h = { yomomma => q!so fat! };
 
 print deref("$h")->{yomomma};
 
+my $val = deref("HASH(0x0)");
+# doesnt die, returns undef
+
+
